#include "srm_client.h"

#include "../../misc/log_time.h"

#include <string>
#include <list>

class SRMClientTest {
  
private:
  SRMClientRequest* req;
  SRMClient* client;
public:
  SRMClientTest(std::string);
  ~SRMClientTest();
  int test_getTURLs();
  int test_info();

};

SRMClientTest::SRMClientTest(std::string url) {

  std::list<std::string> urls;
  urls.push_back(url);

  req = new SRMClientRequest(urls);
  bool timeout = false;
  client = SRMClient::getInstance(url, timeout, "", 30);

};

SRMClientTest::~SRMClientTest() {
  delete req;
  delete client;
};

int SRMClientTest::test_getTURLs() {


  std::list<std::string> turls;

  client->getTURLs(*req, turls);

  for (std::list<std::string>::iterator i = turls.begin();
       i != turls.end();
       ++i) {
    odlog(DEBUG) << "TURL: " << *i << std::endl;
  };

  return 0;
};

int SRMClientTest::test_info() {

  std::list<struct SRMFileMetaData> metadata;

  client->info(*req, metadata);
  if(!metadata.empty()) {
    // size is a random int if not defined, so check path is defined
    if(metadata.front().path != "") {
      odlog(DEBUG) << "size: " << metadata.front().size << std::endl;
    };
    if(metadata.front().checkSumType != "" &&
       metadata.front().checkSumValue != "") {
      odlog(DEBUG) << "checksum: " << metadata.front().checkSumType << ": " << metadata.front().checkSumValue << std::endl;
    };
  };
  return 0;
};

int main() {

  // set logging
  LogTime::Active(true);
  LogTime::Level(VERBOSE);


  SRMClientTest* test = new SRMClientTest(std::string("srm://srm.ndgf.org/srm/managerv1?SFN=/pnfs/ndgf.org/data/atlas/disk/trig1_misal1_mc12_V1/AOD/trig1_misal1_mc12_V1.005001.pythia_minbias.recon.AOD.v13003002_tid016479/AOD.016479._04261.pool.root.2"));

  test->test_getTURLs();
  test->test_info();
  delete test;
  return 0;
};
