AC_DEFUN([NORDUGRID_INIT],
[

AC_REQUIRE([ARC_PREPARE_PREFIX])

dnl --with-docdir since older autoconf (<2.60) does not support --docdir
AC_ARG_WITH([docdir],
AC_HELP_STRING([--with-docdir=DIR],
  [Install documentation in DIR [[default: ${datadir}/doc]]]),
  [case $withval in 
    yes|no)
      AC_MSG_ERROR([Invalid DIR])
      ;;
    *)
      docdir="$withval"
      ;;
  esac
],
[
  if test -z "$docdir"; then
    docdir='${datadir}/doc'
  fi
])
AC_SUBST(docdir)

dnl Useful C/C++ compiler flags
dnl
CC_MISC_FLAGS=

dnl
dnl Try to use -ansi switch to force people write ASNI code
dnl
if test "x$CC" = "xgcc"; then
  CC_MISC_FLAGS="$CC_MISC_FLAGS -ansi"
fi
AC_SUBST(CC_MISC_FLAGS)

dnl
dnl Check for the pthread library
dnl
AC_CHECK_LIB([pthread], [pthread_mutex_init],
AC_TRY_COMPILE(
[#include <pthread.h>],
[#ifndef pthread_yield
  char *p = (char *) pthread_yield;
#endif
],AC_DEFINE(HAVE_PTHREAD_YIELD,,[Is pthread_yield declared])
)
)

AH_VERBATIM([NOT_HAVE_PTHREAD_YIELD],
#ifndef HAVE_PTHREAD_YIELD
#define pthread_yield sched_yield
#endif
)dnl


dnl
dnl gSOAP
dnl
gsoap=yes
AC_ARG_WITH(gsoap-location,
  [  --with-gsoap-location=<PATH>         Specify the gSOAP installation path. [[autodetect]]],
  [ AC_PATH_PROG(soapcpp2, soapcpp2, not found, $with_gsoap_location/bin) ],
  [ AC_PATH_PROG(soapcpp2, soapcpp2, not found) ]
)
if test "x$soapcpp2" = "xnot found"; then
  gsoap_location=""
  gsoap=
  SOAPCPP2=:
  WSDL2H=:
else
  gsoap_location=`echo "$soapcpp2" | sed -e 's%/bin/soapcpp2$%%' -e 't' -e 's%.*%%'`
  SOAPCPP2=$gsoap_location/bin/soapcpp2
  WSDL2H=$gsoap_location/bin/wsdl2h

  PKG_CHECK_MODULES(GSOAP, gsoap++)
  if test x"$GSOAP_LIBS" = x ; then
    AC_MSG_WARN([No gSOAP library found. Please install gSOAP.])
    gsoap=
  fi
  GSOAP_INCLUDES=$GSOAP_CFLAGS
  AC_SUBST(GSOAP_INCLUDES)
  AC_SUBST(GSOAP_LIBS)

dnl
dnl gSOAP version
dnl
AC_MSG_CHECKING(for gSOAP version)
gsoap_version=`$gsoap_location/bin/soapcpp2 -v 2>&1 | sed -e 's/.*release \([[^ ]]*\).*/\1/' -e 't new' -e 's/^.*Compiler for C and C++ *\([[^ ]]*\).*/\1/' -e 't matched' -e 's/.*//' -e ':matched' -e ':new' | grep '.'`
if test "x$gsoap_version" = "x"; then
  AC_MSG_WARN([Could not determine version.])
  gsoap=
fi
gsoap_version_major=`echo "$gsoap_version" | sed -e 's/^\([[^\.]]\).*/\1/' -e 't match' -e 's/.*/0/' -e ':match'`
gsoap_version_minor=`echo "$gsoap_version" | sed -e 's/^[[^\.]]*\.\([[^\.]]*\).*/\1/' -e 't match' -e 's/.*/0/' -e ':match'`
gsoap_version_subminor=`echo "$gsoap_version" | sed -e 's/^[[^\.]]*\.[[^\.]]*\.\([[0-9]]*\).*/\1/' -e 't match' -e 's/.*/0/' -e ':match'`
OLD_GSOAP=
AC_MSG_RESULT($gsoap_version_major.$gsoap_version_minor.$gsoap_version_subminor)
if test "$gsoap_version_major" -lt "2"; then
  AC_MSG_WARN([found gSOAP version $gsoap_version_major.$gsoap_version_minor.$gsoap_version_subminor - gSOAP with version below 2.7.2 is not supported anymore])
  gsoap=
fi
if test "$gsoap_version_major" -eq "2"; then
  if test "$gsoap_version_minor" -lt "7" ; then
    AC_MSG_WARN([found gSOAP version $gsoap_version_major.$gsoap_version_minor.$gsoap_version_subminor - gSOAP with version below 2.7.2 is not supported anymore])
    gsoap=
  fi
  if test "$gsoap_version_minor" -eq "7" && test "$gsoap_version_subminor" -lt "2" ; then
    AC_MSG_WARN([found gSOAP version $gsoap_version_major.$gsoap_version_minor.$gsoap_version_subminor - gSOAP with version below 2.7.2 is not supported anymore])
    gsoap=
  fi
fi

cat > gsoaptest.xsd <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<xsd:schema xmlns:xsd="http://www.w3.org/2001/XMLSchema" elementFormDefault="qualified">
	<xsd:complexType name="X">
		<xsd:sequence>
			<xsd:element ref="Y"/>
		</xsd:sequence>
	</xsd:complexType>
	<xsd:element name="Y" type="xsd:string"/>
</xsd:schema>
EOF

${WSDL2H} -s gsoaptest.xsd

${SOAPCPP2} -p gsoaptest gsoaptest.h

AC_LANG_SAVE
AC_LANG_CPLUSPLUS
CXXFLAGS_SAVE=$CXXFLAGS
CXXFLAGS="$CXXFLAGS $GSOAP_INCLUDES"
AC_TRY_COMPILE([#include "gsoaptestStub.h"],
    [ns1__X x; x.Y = "";],
    [use_namespaces="no"],
    [AC_TRY_COMPILE([#include "gsoaptestStub.h"],
	[ns1__X x; x.ns1__Y = "";],
	[use_namespaces="yes"],
	[gsoap=])
    ]
)

CXXFLAGS=$CXXFLAGS_SAVE
AC_LANG_RESTORE

rm -rf gsoaptest* ns1.nsmap

if test "x$use_namespaces" = "xyes"; then
  AC_DEFINE(GSOAP_ALWAYS_USES_NAMESPACES_FOR_MEMBER_NAMES,,[define if gSOAP prepends names of class members with namespace])
fi

fi

if test "$gsoap" == "yes"; then
  :
else
  AC_MSG_WARN([gSoap not found - many things will not be built])
fi

AC_SUBST(SOAPCPP2)
AC_SUBST(WSDL2H)
AC_SUBST(GSOAP_LIBS)
AC_SUBST(GSOAP_LOCATION,$gsoap_location)
AM_CONDITIONAL(HAVE_GSOAP, test "x$gsoap" = "xyes")

XML_LIBS=
AC_ARG_WITH(xml-location,
  [  --with-libxml-location=<PATH>        Specify the libxml2 installation path. [[autodetect]]],
  [ AC_PATH_PROG(xml_config, xml2-config, not found, $with_libxml_location/bin) ],
  [ AC_PATH_PROG(xml_config, xml2-config, not found) ]
)
if test "x$xml_config" != "xnot found"; then
  XML_INCLUDES=`$xml_config --cflags`
  # Remove /usr/include
  XML_INCLUDES=`echo $XML_INCLUDES | sed -e 's, *-I/usr/include/*$, ,g' -e 's, *-I/usr/include/* , ,g'`
  XML_LIBS=`$xml_config --libs`
fi
AC_SUBST(XML_INCLUDES)
AC_SUBST(XML_LIBS)
AM_CONDITIONAL(HAVE_LIBXML, test "x$xml_config" != "xnot found")

# globus/gpt packages
PKG_CHECK_MODULES(GLOBUS_COMMON, [globus-common], [
GLOBUS_COMMON_VERSION=`$PKG_CONFIG --modversion globus-common`], [
GPT_PKG(globus_common)
])
AC_SUBST(GLOBUS_COMMON_CFLAGS)
AC_SUBST(GLOBUS_COMMON_LIBS)

PKG_CHECK_MODULES(GLOBUS_GSI_CREDENTIAL, [globus-gsi-credential], [
GLOBUS_GSI_CREDENTIAL_VERSION=`$PKG_CONFIG --modversion globus-gsi-credential`], [
GPT_PKG(globus_rls_client)
])
AC_SUBST(GLOBUS_GSI_CREDENTIAL_CFLAGS)
AC_SUBST(GLOBUS_GSI_CREDENTIAL_LIBS)

PKG_CHECK_MODULES(GLOBUS_GSI_SYSCONFIG, [globus-gsi-sysconfig], [
GLOBUS_GSI_SYSCONFIG_VERSION=`$PKG_CONFIG --modversion globus-gsi-sysconfig`], [
GPT_PKG(globus_rls_client)
])
AC_SUBST(GLOBUS_GSI_SYSCONFIG_CFLAGS)
AC_SUBST(GLOBUS_GSI_SYSCONFIG_LIBS)

PKG_CHECK_MODULES(GLOBUS_RLS_CLIENT, [globus-rls-client], [
GLOBUS_RLS_CLIENT_VERSION=`$PKG_CONFIG --modversion globus-rls-client`], [
GPT_PKG(globus_rls_client)
])
AC_SUBST(GLOBUS_RLS_CLIENT_CFLAGS)
AC_SUBST(GLOBUS_RLS_CLIENT_LIBS)

PKG_CHECK_MODULES(GLOBUS_GSSAPI_GSI, [globus-gssapi-gsi], [
GLOBUS_GSSAPI_VERSION=`$PKG_CONFIG --modversion globus-gssapi-gsi`], [
GPT_PKG(globus_gssapi_gsi)
])
AC_SUBST(GLOBUS_GSSAPI_GSI_CFLAGS)
AC_SUBST(GLOBUS_GSSAPI_GSI_LIBS)

PKG_CHECK_MODULES(GLOBUS_FTP_CLIENT, [globus-ftp-client], [
GLOBUS_FTP_CLIENT_VERSION=`$PKG_CONFIG --modversion globus-ftp-client`], [
GPT_PKG(globus_ftp_client)
])
AC_SUBST(GLOBUS_FTP_CLIENT_CFLAGS)
AC_SUBST(GLOBUS_FTP_CLIENT_LIBS)

PKG_CHECK_MODULES(GLOBUS_FTP_CONTROL, [globus-ftp-control], [
GLOBUS_FTP_CONTROL_VERSION=`$PKG_CONFIG --modversion globus-ftp-control`], [
GPT_PKG(globus_ftp_control)
])
AC_SUBST(GLOBUS_FTP_CONTROL_CFLAGS)
AC_SUBST(GLOBUS_FTP_CONTROL_LIBS)

PKG_CHECK_MODULES(GLOBUS_RSL, [globus-rsl], [
GLOBUS_RSL_VERSION=`$PKG_CONFIG --modversion globus-rsl`], [
GPT_PKG(globus_rsl)
])
AC_SUBST(GLOBUS_RSL_CFLAGS)
AC_SUBST(GLOBUS_RSL_LIBS)

PKG_CHECK_MODULES(GLOBUS_IO, [globus-io], [
GLOBUS_IO_VERSION=`$PKG_CONFIG --modversion globus-io`], [
GPT_PKG(globus_io)
])
AC_SUBST(GLOBUS_IO_CFLAGS)
AC_SUBST(GLOBUS_IO_LIBS)

PKG_CHECK_MODULES(GLOBUS_GSI_PROXY_CORE, [globus-gsi-proxy-core], [
GLOBUS_GSI_PROXY_CORE_VERSION=`$PKG_CONFIG --modversion globus-gsi-proxy-core`], [
GPT_PKG(globus_gsi_proxy_core)
])
AC_SUBST(GLOBUS_GSI_PROXY_CORE_CFLAGS)
AC_SUBST(GLOBUS_GSI_PROXY_CORE_LIBS)

PKG_CHECK_MODULES(GLOBUS_GSS_ASSIST, [globus-gss-assist], [
GLOBUS_GSS_ASSIST_VERSION=`$PKG_CONFIG --modversion globus-gss-assist`], [
GPT_PKG(globus_gss_assist)
])
AC_SUBST(GLOBUS_GSS_ASSIST_CFLAGS)
AC_SUBST(GLOBUS_GSS_ASSIST_LIBS)

PKG_CHECK_MODULES(GLOBUS_OPENSSL, [globus-openssl], [
GLOBUS_OPENSSL_VERSION=`$PKG_CONFIG --modversion globus-openssl`], [
GPT_PKG(globus_openssl)
])
AC_SUBST(GLOBUS_OPENSSL_CFLAGS)
AC_SUBST(GLOBUS_OPENSSL_LIBS)

GLOBUS_INCLUDES="$GLOBUS_COMMON_CFLAGS $GLOBUS_OPENSSL_CFLAGS"
AC_SUBST(GLOBUS_INCLUDES)

# Check for new globus thread model selection
SAVE_CFLAGS=$CFLAGS
SAVE_LIBS=$LIBS
CFLAGS="$CFLAGS $GLOBUS_COMMON_CFLAGS"
LIBS="$LIBS $GLOBUS_COMMON_LIBS"
AC_CHECK_FUNCS(globus_thread_set_model)
CFLAGS=$SAVE_CFLAGS
LIBS=$SAVE_LIBS

# Check for gridftp-v2
SAVE_CFLAGS=$CFLAGS
SAVE_LIBS=$LIBS
CFLAGS="$CFLAGS $GLOBUS_FTP_CLIENT_CFLAGS"
LIBS="$LIBS $GLOBUS_FTP_CLIENT_LIBS"
AC_CHECK_FUNCS(globus_ftp_client_handleattr_set_gridftp2)
CFLAGS=$SAVE_CFLAGS
LIBS=$SAVE_LIBS

SAVE_CPPFLAGS=$CPPFLAGS
CPPFLAGS="$CPPFLAGS $GLOBUS_INCLUDES $MYPROXY_CFLAGS"
AC_CHECK_HEADERS([globus_rls_client.h],[rls_supported=yes],[rls_supported=no])
AC_CHECK_HEADERS([sasl.h],sasl_supported=yes,sasl_supported=no)
AC_CHECK_HEADERS([sasl/sasl.h],sasl_supported=yes,sasl_supported=no)
CPPFLAGS=$SAVE_CPPFLAGS

if test "x$GLOBUS_IO_VERSION" = "x"; then
  IO_VERSION_MAJOR=0
else
  IO_VERSION_MAJOR=`echo "$GLOBUS_IO_VERSION" | sed 's/^\([[^.]]\).*/\1/'`;
fi
AC_DEFINE_UNQUOTED(GLOBUS_IO_VERSION,$IO_VERSION_MAJOR,[Globus IO version])

# Check for the globus_gss_assist_authorization_host_name function
SAVE_CFLAGS=$CFLAGS
SAVE_LIBS=$LIBS
CFLAGS="$CFLAGS $GLOBUS_GSS_ASSIST_CFLAGS"
LIBS="$LIBS $GLOBUS_GSS_ASSIST_LIBS"
AC_CHECK_FUNCS(globus_gss_assist_authorization_host_name)
CFLAGS=$SAVE_CFLAGS
LIBS=$SAVE_LIBS

dnl
dnl Choose OpenLDAP package to use
dnl
AC_ARG_ENABLE(globus_openldap,
  [  --enable-globus-openldap          Use OpenLDAP provided as part of Globus],  
  [
    case "${enableval}" in
      yes)
	globus_openldap=yes
	AC_MSG_NOTICE(globus openldap was enabled)
	;;
      no)
	globus_openldap=no
	AC_MSG_NOTICE(globus openldap was disabled)
	;;
      *)
	AC_MSG_ERROR(bad value ${enableval} for --enable-globus-openldap)
	;;
    esac
  ],
  [ globus_openldap= ]
)

dnl
dnl Autodetect suitable OpenLDAP if user not specified
dnl
if test "x$globus_openldap" = "x"; then
  AC_MSG_CHECKING(if Globus uses own OpenSSL)
  if test -f "${GLOBUS_LOCATION:-/usr}/lib/libglobus_ftp_client.so" -o \
          -f "${GLOBUS_LOCATION:-/usr}/lib64/libglobus_ftp_client.so"; then
    if test "x$LIBLDAP" = "x"; then
      AC_MSG_ERROR(no - need independent OpenLDAP - please install)
    else
      AC_MSG_RESULT(no - will use previously detected OpenLDAP)
    fi
  elif test -f "${GLOBUS_LOCATION:-/usr}/lib/libglobus_ftp_client_$GPT_FLAVOR.so"; then
    ldd "${GLOBUS_LOCATION:-/usr}/lib/libglobus_ftp_client_$GPT_FLAVOR.so" 2>/dev/null | grep "libssl_$GPT_FLAVOR" 2>/dev/null 1>/dev/null
    if test $? = 0; then
      AC_MSG_RESULT(yes - must use Globus OpenLDAP)
      globus_openldap=yes
    else
      if test "x$LIBLDAP" = "x"; then
        AC_MSG_ERROR(no - need independent OpenLDAP - please install)
      else
        AC_MSG_RESULT(no - will use previously detected OpenLDAP)
      fi
    fi
  else
    AC_MSG_ERROR(can't check - install Globus FTP Client library of flavor $GPT_FLAVOR or specify which OpenLDAP to use explicitely)
  fi
fi

dnl
dnl Check for Globus OpenLDAP 
dnl
if test "x$globus_openldap" = "xyes"; then
  SAVE_LDFLAGS=$LDFLAGS
  LDFLAGS="-L${GLOBUS_LOCATION:-/usr}/lib -llber_$GPT_FLAVOR -lpthread"
  AC_CHECK_LIB([ldap_r_$GPT_FLAVOR], [ldap_first_message], [ LIBLDAP="-L${GLOBUS_LOCATION:-/usr}/lib -lldap_r_$GPT_FLAVOR -llber_$GPT_FLAVOR" ], [
    AC_CHECK_LIB([ldap_$GPT_FLAVOR], [ldap_first_message], [ LIBLDAP="-L${GLOBUS_LOCATION:-/usr}/lib -lldap_$GPT_FLAVOR -llber_$GPT_FLAVOR" ], [
      AC_MSG_ERROR(Missing OpenLDAP libraries of flavor $GPT_FLAVOR in Globus installation)
    ])
  ])
  AC_SUBST(LIBLDAP)
  LDFLAGS=$SAVE_LDFLAGS
fi

dnl
dnl Enable LFC
dnl
lfc=true
AC_ARG_ENABLE(lfc,
  [  --disable-lfc                      Disable LFC support],  
  [
    case "${enableval}" in
      yes) lfc=true ;;
      no)  lfc=false; AC_MSG_WARN(LFC will be disabled) ;;
      *)   AC_MSG_ERROR(bad value ${enableval} for --disable-lfc) ;;
    esac
  ],
  [ lfc=true ]
)

if test "x$lfc" = xtrue ; then

dnl
dnl LFC_LOCATION
dnl
DEFAULT_LFC_LOCATION=/opt/glite
LFC_LOCATION=
AC_ARG_WITH(lfc-location,
  [  --with-lfc-location=<PATH>           Specify the LFC installation path. [[/opt/glite]]],
  [ 
    LFC_LOCATION=$with_lfc_location
    if test ! -d $LFC_LOCATION; then
      AC_MSG_WARN([LFC_LOCATION ($LFC_LOCATION) does not exist])
      LFC_LOCATION=
    fi
  ],[
    if test "x$LFC_LOCATION" = "x"; then
      LFC_LOCATION=$DEFAULT_LFC_LOCATION
    fi
    if test ! -d $LFC_LOCATION; then
      LFC_LOCATION=
    fi
  ]
)

dnl
dnl Check for LFC api availability
dnl
LFC_INCLUDES=""
if test -d /usr/include/lfc; then
  LFC_INCLUDES="-I/usr/include/lfc"
fi
if test "x$LFC_LOCATION" != "x"; then
  LFC_INCLUDES=-I$LFC_LOCATION/include/lfc
fi
AC_SUBST(LFC_INCLUDES)

LFC_LIBS=
SAVE_CPPFLAGS=$CPPFLAGS
CPPFLAGS="$LFC_INCLUDES"
AC_CHECK_HEADERS([lfc_api.h],
  LFC_LDFLAGS="-ldl -lpthread"
  if test "x$LFC_LOCATION" != "x"; then
    if test -d $LFC_LOCATION/lib64; then
      LFC_LDFLAGS="-L$LFC_LOCATION/lib64 -ldl -lpthread"
    else
      LFC_LDFLAGS="-L$LFC_LOCATION/lib -ldl -lpthread"
    fi

  fi
  SAVE_LDFLAGS=$LDFLAGS
  LDFLAGS="$LDFLAGS $LFC_LDFLAGS"
  AC_CHECK_LIB(lfc,lfc_startsess, LFC_LIBS="$LFC_LDFLAGS -llfc",lfc=false,)
  # Check if lcgdm is a separate library
  AC_CHECK_LIB([lcgdm], [C__serrno], [LFC_LIBS="$LFC_LIBS -llcgdm"],
  AC_CHECK_LIB([lfc], [C__serrno], [], [lfc="false"]))
  LDFLAGS=$SAVE_LDFLAGS
  ,
  lfc=false
)
CPPFLAGS=$SAVE_CPPFLAGS
AC_SUBST(LFC_LIBS)

fi

if test "x$lfc" != xtrue ; then
  AC_MSG_WARN(LFC will be disabled)
  lfc_supported="no"
else
  AC_DEFINE(HAVE_LFC_API_H,,[gLite LFC])
  lfc_supported="yes"
fi
 
AM_CONDITIONAL(HAVE_LFC, test "x$lfc" = xtrue)

AM_CONDITIONAL(BUILD_SRM, test "x$WSDL2H" != "x")
AM_CONDITIONAL(BUILD_JSDL, test "x$WSDL2H" != "x" && test "x$OLD_GSOAP" = "x")

if test "x$WSDL2H" = "x"; then
  AC_DEFINE(SRM_MISSING,,[Can't build SRM code])
  srm_supported="no"
else
  srm_supported="yes"
fi

if test "x$WSDL2H" = "x" || test "x$OLD_GSOAP" != "x" ; then
  AC_DEFINE(JSDL_MISSING,,[Can't build JSDL code])
  jsdl_supported="no"
else
  jsdl_supported="yes"
fi

dnl
dnl Python
dnl
AC_ARG_ENABLE(python,
  AC_HELP_STRING([--disable-python], [disable the Python binding]),
  [enables_python=$enableval], [enables_python=yes])
if test "$enables_python" = "yes"; then

  AC_ARG_WITH(python, AC_HELP_STRING([--with-python=(PYTHON)],
    [set the full path to the python program to use]))

  AC_CHECK_PROGS(PYTHON, $with_python python)

  if test "X$PYTHON" != "X"; then
    changequote(<<, >>)dnl
    PYTHON_VERSION=`$PYTHON -c 'import sys; print(sys.version[:3])'`
    PYTHON_CFLAGS=-I`$PYTHON -c 'from distutils import sysconfig; print(sysconfig.get_python_inc())'`
    PY_LIBS=`$PYTHON -c "from distutils import sysconfig; print(sysconfig.get_config_vars().get('LIBS'))" | sed s/None//`
    PY_SYSLIBS=`$PYTHON -c "from distutils import sysconfig; print(sysconfig.get_config_vars().get('SYSLIBS'))" | sed s/None//`
    PY_LIBDEST=`$PYTHON -c "from distutils import sysconfig; print(sysconfig.get_config_vars().get('LIBDEST'))" | sed s/None//`
    PYTHON_SITE_PACKAGES=`$PYTHON -c 'from distutils import sysconfig; print(sysconfig.get_python_lib(1,0,"${prefix}"))'`
    changequote([, ])dnl
    PYTHON_LIBS="$PY_LIBS $PY_SYSLIBS"
    SAVE_LDFLAGS=$LDFLAGS
    LDFLAGS="$PYTHON_LIBS $LDFLAGS"
    AC_CHECK_LIB([python$PYTHON_VERSION], [Py_Initialize],[
        AC_MSG_NOTICE([No additional path to python library needed])
        PYTHON_LIBS="-lpython$PYTHON_VERSION $PYTHON_LIBS"],[
        LDFLAGS="-L$PY_LIBDEST/config $LDFLAGS"
        # check a different symbol or else configure will used cached value
        AC_CHECK_LIB([python$PYTHON_VERSION], [Py_Finalize],[
            AC_MSG_NOTICE([Adding path to python library])
            PYTHON_LIBS="-L$PY_LIBDEST/config -lpython$PYTHON_VERSION $PYTHON_LIBS"],[
            AC_ERROR([Can't find python library])])])
    LDFLAGS=$SAVE_LDFLAGS
    AC_SUBST(PYTHON_VERSION)
    AC_SUBST(PYTHON_CFLAGS)
    AC_SUBST(PYTHON_LIBS)
    AC_SUBST(PYTHON_SITE_PACKAGES)
  fi

  if test "X$PYTHON" == "X"; then
    AC_MSG_NOTICE([Missing Python - skipping Python bindings])
    enables_python=no
  else
    AC_MSG_NOTICE([Python available: $PYTHON_VERSION])
  fi
fi

AM_CONDITIONAL([PYTHON_ENABLED],[test "x$enables_python" = "xyes"])

]
)
