/*
 * SWIG interface file
 */


%module arclib
%{

#include <arc/error.h>
#include <arc/broker.h>
#include <arc/certificate.h>
#include <arc/common.h>
#include <arc/condition.h>
#include <arc/datetime.h>
#include <arc/ftpcontrol.h>
#include <arc/giis.h>
#include <arc/jobftpcontrol.h>
#include <arc/joblist.h>
#include <arc/jobsubmission.h>
#include <arc/ldapquery.h>
#include <arc/mdsdiscovery.h>
#include <arc/mdsparser.h>
#include <arc/mdsquery.h>
#include <arc/notify.h>
#include <arc/resource.h>
#include <arc/runtimeenvironment.h>
#include <arc/standardbrokers.h>
#include <arc/stringconv.h>
#include <arc/target.h>
#include <arc/url.h>
#include <arc/xrsl.h>

#include <ctime>

%}

typedef long time_t;

%include "std_string.i"
%include "std_list.i"
%include "std_vector.i"
%include "std_except.i"
%include "exception.i"
%include "std_map.i"
%include "std_multimap.i"

%feature("exceptionclass") ARCLibError;

%rename("XrslRelationList") XrslRelation(const std::string&, const
xrsl_operator&, const std::list<std::string>&);

%rename("XrslRelationDoubleList") XrslRelation(const std::string&, const
xrsl_operator&, const std::list<std::list<std::string> >&);

%std_nodefconst_type(URL)
%template(url_list) std::list<URL>;
%std_nodefconst_type(RuntimeEnvironment)
%template(re_list) std::list<RuntimeEnvironment>;
%std_nodefconst_type(Target)
%template(target_list) std::list<Target>;
%std_nodefconst_type(XrslRelation)
%template(xrslrelation_list) std::list<XrslRelation>;

%template(string_list) std::list<std::string>;
%template(stringstringlist) std::list<std::list<std::string> >;

%template(xrsl_list) std::list<Xrsl>;
%template(cert_list) std::list<Certificate>;
%template(job_list) std::list<Job>;
%template(cluster_list) std::list<Cluster>;
%template(queue_list) std::list<Queue>;
%template(user_list) std::list<User>;
%template(se_list) std::list<StorageElement>;
%template(rc_list) std::list<ReplicaCatalog>;
%template(fileinfo_list) std::list<FileInfo>;

%template(string_vector) std::vector<std::string>;
%template() std::pair<long,int>;
%template(map_long_int) std::map<long,int>;
%template() std::pair<int,int>;
%template(map_int_int) std::map<int,int>;
%template() std::pair<std::string,float>;
%template(map_string_float) std::map<std::string,float>;
%template() std::pair<std::string,std::string>;
%template(map_string_string) std::map<std::string,std::string>;
%template(multimap_string_string) std::multimap<std::string,std::string>;

// Rename everything str to __str__
// This makes stuff looks good in Python for classes
// which has str() method.
%rename(__str__) str;

%apply const std::string& { std::string* };
%apply std::list<Target>& INOUT { std::list<Target>& targets };
%apply std::list<Queue>& INOUT { std::list<Queue>& queues };

# Rename what to __str__ in top exception
%extend ARCLibError {
	std::string __str__() {
		return std::string(self->what());
	}
}

%extend Certificate {
	std::string __str__() {
		return self->GetSN();
	}
}

%extend Cluster {
	std::string __str__() {
		return "Cluster: " + self->hostname + "  " + self->alias;
	}
}

%extend Queue {
	std::string __str__() {
		return "Queue: " + self->name + " at " + self->cluster.hostname;
	}
}

%extend Job {
	std::string __str__() {
		return "Job: " + self->id;
	}
}

%extend FileInfo {
	std::string __str__() {
		std::string ret = self->filename + "  ";
		ret += tostring(self->size) + "  ";
		if (self->isdir) ret += "dir";
		if (!self->isdir) ret += "file";
		return ret;
	}
}

%extend FTPControl {
	std::list<FileInfo> ListDir(const std::string& urlstr,
	                            int timeout = TIMEOUT,
	                            bool disconnectafteruse = true)
	throw(FTPControlError, URLError) {
		URL url(urlstr);
		return self->ListDir(url, timeout, disconnectafteruse);
	}

	std::list<FileInfo> RecursiveListDir(const std::string& urlstr,
	                                     int timeout = TIMEOUT,
	                                     bool disconnectafteruse = true)
	throw(FTPControlError, URLError) {
		URL url(urlstr);
		return self->RecursiveListDir(url, timeout, disconnectafteruse);
	}

	unsigned long long Size(const std::string& urlstr,
	                        int timeout = TIMEOUT,
	                        bool disconnectafteruse = true)
	throw(FTPControlError, URLError) {
		URL url(urlstr);
		return self->Size(url, timeout, disconnectafteruse);
	}

	void DownloadDirectory(const std::string& urlstr,
	                       const std::string& localdir,
	                       int timeout = TIMEOUT,
	                       bool disconnectafteruse = true)
	throw(FTPControlError, URLError) {
		URL url(urlstr);
		self->DownloadDirectory(url, localdir, timeout, disconnectafteruse);
	}

	void Download(const std::string& urlstr,
	              const std::string& localfile,
	              int timeout = TIMEOUT,
	              bool disconnectafteruse = true)
	throw(FTPControlError, URLError) {
		URL url(urlstr);
		self->Download(url, localfile, timeout, disconnectafteruse);
	}

	void Upload(const std::string& localfile,
	            const std::string& urlstr,
	            int timeout = TIMEOUT,
	            bool disconnectafteruse = true)
	throw(FTPControlError, URLError) {
		URL url(urlstr);
		self->Upload(localfile, url, timeout, disconnectafteruse);
	}
}

%extend JobFTPControl {
	std::string Submit(const std::string& urlstr,
	                   const std::string& rsl,
	                   int timeout = TIMEOUT,
	                   bool disconnectafteruse = true)
	throw(JobFTPControlError, FTPControlError, URLError) {
		URL url(urlstr);
		return self->Submit(url, rsl, timeout, disconnectafteruse);
	}

	std::string Submit(const std::string& urlstr,
	                   const std::string& rsl,
	                   std::multimap<std::string, std::string>& files,
	                   int timeout = TIMEOUT,
	                   bool disconnectafteruse = true)
	throw(JobFTPControlError, FTPControlError, URLError) {
		URL url(urlstr);
		return self->Submit(url, rsl, files, timeout, disconnectafteruse);
	}
}

# Make swig generation complain a bit less
%ignore Time::operator=(time_t);
%ignore URL::operator=(const URL& url);
%ignore Xrsl::operator=(const Xrsl& url);
%ignore URL::operator=(const std::string& urlstr);

#ifdef SWIG<python>
// Grab a Python function object as a Python object.
%typemap(in) PyObject *pyfunc {
	if (!PyCallable_Check($input)) {
		PyErr_SetString(PyExc_TypeError, "Need a callable object!");
		return NULL;
	}
	$1 = $input;
}
#endif

%{
/*
 * This function matches the prototype of the normal C callback function for
 * LdapQuery::Query. However we use the *ref pointer to hold a reference to
 * callable Python object. Use lambda or nested functions in Python instead
 * of ref.
 */
static void PythonCallback(const std::string& attr, const std::string& value, void *ref)
{
	PyObject *func, *arglist, *result;

	func = (PyObject *) ref;	// Get python function

	char *attr_  = (char *) attr.c_str();
	char *value_ = (char *) value.c_str();
	arglist = Py_BuildValue("(ss)", attr_, value_); // Build argument list

	result = PyEval_CallObject(func, arglist);      // Invoke Python callback
	Py_DECREF(arglist); // Trash arglist

	// No need to look at result since return is void
	Py_XDECREF(result);

	return;
}
%}

%include <arc/error.h>
%include <arc/broker.h>
%include <arc/certificate.h>
%include <arc/common.h>
%include <arc/condition.h>
%include <arc/datetime.h>
%include <arc/ftpcontrol.h>
%include <arc/giis.h>
%include <arc/jobftpcontrol.h>
%include <arc/joblist.h>
%include <arc/jobsubmission.h>
%include <arc/ldapquery.h>
%include <arc/mdsdiscovery.h>
%include <arc/mdsparser.h>
%include <arc/mdsquery.h>
%include <arc/notify.h>
%include <arc/resource.h>
%include <arc/runtimeenvironment.h>
%include <arc/standardbrokers.h>
%include <arc/stringconv.h>
%include <arc/target.h>
%include <arc/url.h>
%include <arc/xrsl.h>

// Attach a new method to ldapquery for adding python function
%extend LdapQuery {
	// Set a Python function object as a callback function
	// Note : PyObject *pyfunc is remapped with a typempap

	void Query(const std::string& base,
	           const std::string& filter,
	           const std::vector <std::string>& attributes,
			   Scope scope, PyObject *pyfunc) {

		self->Query(base, filter, attributes, scope);
		self->Result(PythonCallback, (void *) pyfunc);
	           
		Py_INCREF(pyfunc);
	}
}
